@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-2003 by Solar Designer
+ * Copyright (c) 1996-2004 by Solar Designer
  */
 
 #include <stdio.h>
@@ -79,7 +79,7 @@ static struct opt_entry opt_list[] = {
 
 #define JOHN_USAGE \
 "John the Ripper password cracker, version " JOHN_VERSION "\n" \
-"Copyright (c) 1996-2003 by " JOHN_COPYRIGHT "\n" \
+"Copyright (c) 1996-2004 by " JOHN_COPYRIGHT "\n" \
 "Homepage: http://www.openwall.com/john/\n" \
 "\n" \
 "Usage: %s [OPTIONS] [PASSWORD-FILES]\n" \
@@ -100,8 +100,8 @@ static struct opt_entry opt_list[] = {
 "--shells=[-]SHELL[,..]     load users with[out] this (these) shell(s) only\n" \
 "--salts=[-]COUNT           load salts with[out] at least COUNT passwords " \
 	"only\n" \
-"--format=NAME              force ciphertext format NAME " \
-	"(DES/BSDI/MD5/BF/AFS/LM)\n" \
+"--format=NAME              force ciphertext format NAME: " \
+	"DES/BSDI/MD5/BF/AFS/LM\n" \
 "--save-memory=LEVEL        enable memory saving, at LEVEL 1..3\n"
 
 void opt_init(int argc, char **argv)
